package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0`````````````"`!0````!$``98````#0``,*H```````T`"``
M"0`H`!\`'@````8````T$```-!```#0```$@```!(`````4````$`````P``
M`500``%4$``!5`````T````-````!`````$````!`````!`````0``````"Y
MD```N9`````%``$```````$``+[0$`&^T!`!OM````*(```2T`````8``0``
M`````@``OO`0`;[P$`&^\````0````$`````!@````0````$```!9!```600
M``%D````1````$0````$````!&1TY5```+E0$`"Y4!``N5`````4````%```
M``0````$9'3E40``````````````````````````````!@````1D=.52``"^
MT!`!OM`0`;[0```!,````3`````$`````2]L:6(O;&0N<V\N,0`````````$
M````$`````%'3E4```````````(````&````#P````0````4`````T=.50#@
ME%Y"@LN1XV3$T29/2-Q:OB:7"0```&$```!T````"P``````````````0P``
M``````!(````1P````````!+````6@```#X````Y````3`````,```!8````
M`````#$```!?````50```&H```!L````9P````0````L```````````````J
M````8P```!X``````````````&0```!)````90````D`````````4@```',`
M````````3@`````````?`````````'$`````````40```&X`````````````
M`&8````H`````````#H``````````````'`````U````0````$8`````````
M`````!(`````````/P``````````````(P`````````<````,`````P````R
M````*0```%0``````````````%L```!0````/````%X```!-````.P```#0`
M````````1````````````````````%8```!M`````````$4```!=````0@``
M`#T````G`````0``````````````````````````````````````````````
M``````````````````````````!/````````````````````````````````
M````#P```!0```!@`````````````````````````!,``````````````!$`
M````````&0````````````````````````!9`````````%<`````````:```
M````````````$```````````````%P```!L`````````)@```&D````D````
M"``````````O````)0````X````=`````````&$````A`````````!H````*
M``````````````!!````#0`````````S````+@```&\```!R````7```````
M````````2@````<`````````:P``````````````````````````````````
M`"(``````````````!@`````````-@`````````K````````````````````
M`````!8````&````%0````````!3``````````4```````````````````!B
M````-P`````````"````(````"T````X````)0```$\````(````"`00$`"`
M!$`E```0J*A!AJ("(`1`*00H2T<RHCB(#`2*````3P```%``````````````
M``````!3````50```%8`````````5P```%@`````````60```%H```!;````
M`````%P```````````````````!=````8```````````````80```&,```!D
M````9@````````!H````:P````````!M````;@```&\```!Q`````'&RU<FB
M,/_F+4?>SDG[X*,.[]/J:Z/=I[:;Q2^>X\W;@9SYA]9#"6L+ESH-D`6)Q9[B
M%`T.Y/\A;XL!LD"<N<1\FG]KFYRI?Q_?Q6X<6''9?)+CNWS49-3`XTNM[=MB
M,@H"I^%FS*]F6<D68&M*\'L!QD?B[-5%0SHS[$?%CD%]J6'*E"P_Y<,=T]OR
M8&RA^@[QC;D````````````````````````"X@``````````$@```````+$`
M`````````!(```````.-```````````2```````#>```````````$@``````
M`:$``````````!(```````.]```````````2```````">@``````````$@``
M`````!$``````````"`````````@```````````@```````#?@``````````
M$@```````8T``````````!(```````/>```````````2```````!;@``````
M````$@```````8```````````!(```````,O```````````2```````##@``
M````````$@```````BP``````````!(```````#]```````````2```````"
M'```````````$@```````Z(``````````!(```````'*```````````2````
M```$2```````````$@``````!`T``````````!(```````+S```````````2
M```````"UP``````````$@```````I@``````````!(```````'J````````
M```2```````!I@``````````$@```````C4``````````!(```````/+````
M```````2```````$.@``````````$@```````2\``````````!(```````/6
M```````````2````````-```````````$@```````^@``````````!(`````
M``%=```````````2````````R```````````$@``````!!H``````````!(`
M``````.V```````````2```````$!@``````````$@```````YL`````````
M`!(```````-Q```````````2```````%&P``````````$@```````4$`````
M`````!(```````/V```````````2```````"7```````````$@```````U<`
M`````````!(```````+<```````````2```````"3@``````````$@``````
M`ZD``````````!(```````*1```````````2```````!JP``````````$@``
M`````V```````````!(```````.P```````````2```````#E```````````
M$@```````.P``````````!(```````!"```````````2```````#_0``````
M````$@``````!#(``````````!(```````#7```````````2```````!_@``
M````````$@```````H4``````````!(```````%0```````````2```````#
MA@``````````$@```````T8``````````!(```````,'```````````2````
M```!'0``````````$@``````!"0``````````!(```````)#```````````2
M````````5```````````$@```````=@``````````!(```````!C````````
M```2```````$00``````````$@```````(\``````````!(```````-.````
M```````2```````#00``````````$@```````'@``````````!(```````$+
M```````````2```````!MQ``4Y``````$@``````!840`%UL``!;VA$```\`
M``6/$`!"(```"@@2```-```%NQ``-U````)$$@``#0``!+(0`%F@`````!(`
M``X```1<$`'!8`````0A```;```$BA``,Q`````,$@``#0``!500`%'@````
MM!(```T```"@$`!58``````2```````%/Q`!P4``````$```&0``!4$0`<%`
M`````"```!D```1;$`'!8`````0A```;```$J!``4=`````$$@``#0``!:X0
M`#^0```"D!(```T```3.$``JX````)P2```-```$6A`!P6`````$$0``&P``
M!%40`#S0```"M!(```T```4)$``YH````#@2```-```%)!``._````#8$@``
M#0``!'D0`<%8`````!``__$```2%$`'1H``````0`/_Q```$N!``3#````2,
M$@``#0```R`0`%GH````!!$```\```5%$``98````"02```-```$W!``,B``
M``#H$@``#0``!/T0`#G@```""!(```T```4P$`'!5`````01```:```":A``
M55``````$@``````!)L0`!K0````:!(```T```1R$`'!6``````0`/_Q```%
M@!`!P5`````$$0``&@``!600`"U`````5!(```T```3R$`)!4``````0```:
M```%3!``4,````!($@``#0```J,0`<%P````$Q$``!L```6<$``UL````9@2
M```-```%3A``&1``````$@``#`!L:6)P97)L+G-O+C4N,3``7U]G;6]N7W-T
M87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?
M27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA9W-?
M<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T<@!0
M97)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]C
M;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R7W!T
M<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O<%]E
M;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?
M;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R`%!E
M<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E<FQ?
M9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`
M;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!R96%D`&-L;W-E`%]?97)R;F]?
M;&]C871I;VX`<'1H<F5A9%]G971S<&5C:69I8P!O<&5N-C0`;'-E96LV-`!L
M:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI
M=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`
M=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R
M;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`;65M8W!Y`%]?<W1R;F-P>5]C:&L`
M7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?;&]C`&=E
M='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`')E861D:7(V-`!?
M7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A
M<G1?;6%I;@!?7V5N=FER;VX`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?
M<W1A<G0`7V5N9`!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI
M8F-?8W-U7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE
M86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]31$%?0D%315\`<&%R7V1I<FYA
M;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<VEZ
M95]L;V%D7VUE7S(`7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I
M;FET`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!N86UE7VQO861?;65?
M,@!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G
M`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS`$=,24)#7S(N,RXR
M`$=,24)#7S(N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C```````@````,``P``
M``0``````````P````4```````8`!P`````````#`````P`$``(``@``````
M`P````4``P````,````(```````%``,``P`#``,``P````,````#``(````#
M``,````)``,``P```````P`#`````````````P`#``<````)````````````
M`P````,``P`````````!``$``0`!``,``0`!`````0`!``,``0`!``$``P`!
M``$``0`!``$``0`!``$``0`!``$````!``$``0`!``$``0````$``0`!``8`
M``,6````$````'`-:6D4````"0``!<@````0#6EI$P````@```72````$`EI
M&7(````&```%W````!`-:6D2````!0``!>@````0"6D9=`````0```7R````
M$`UI:1`````#```%_@```````0`"```"QP```!``````#6EI$@````<```7H
M````$`UI:1`````"```%_@`````0`;_P```(%``````0`<%@``!>$P`````0
M`<%P``!Q$P`````0`<`````!%0`````0`<`$```"%0`````0`<`(```#%0``
M```0`<`,```$%0`````0`<`0```%%0`````0`<`4```&%0`````0`<`8```'
M%0`````0`<`<``!/%0`````0`<`@```(%0`````0`<`D```*%0`````0`<`H
M```+%0`````0`<`L```,%0`````0`<`P```-%0`````0`<`T```.%0`````0
M`<`X```/%0`````0`<`\```0%0`````0`<!````1%0`````0`<!$```2%0``
M```0`<!(```3%0`````0`<!,```4%0`````0`<!0```5%0`````0`<!4```6
M%0`````0`<!8```7%0`````0`<!<```8%0`````0`<!@```9%0`````0`<!D
M```:%0`````0`<!H```;%0`````0`<!L```<%0`````0`<!P```=%0`````0
M`<!T```>%0`````0`<!X```?%0`````0`<!\```@%0`````0`<"````A%0``
M```0`<"$```B%0`````0`<"(```C%0`````0`<",``!J%0`````0`<"0``!7
M%0`````0`<"4```D%0`````0`<"8```E%0`````0`<"<```F%0`````0`<"@
M```G%0`````0`<"D```H%0`````0`<"H```I%0`````0`<"L```J%0`````0
M`<"P```K%0`````0`<"T```L%0`````0`<"X```M%0`````0`<"\```N%0``
M```0`<#````O%0`````0`<#$```P%0`````0`<#(```Q%0`````0`<#,```R
M%0`````0`<#0```S%0`````0`<#4```T%0`````0`<#8```U%0`````0`<#<
M```V%0`````0`<#@```W%0`````0`<#D```X%0`````0`<#H```Y%0`````0
M`<#L```Z%0`````0`<#P```[%0`````0`<#T```\%0`````0`<#X```]%0``
M```0`<#\```^%0`````0`<$````_%0`````0`<$$``!`%0`````0`<$(``!!
M%0`````0`<$,``!"%0`````0`<$0``!#%0`````0`<$4``!$%0`````0`<$8
M``!%%0`````0`<$<``!&%0`````0`<$@``!'%0`````0`<$D``!(%0`````0
M`<$H``!)%0`````0`<$L``!*%0`````0`<$P``!+%0`````0`<$T``!,%0``
M```0`<$X``!-%0`````0`<$\``!.%0````"4(?_P?`@"II`!`!23P0`(0I\`
M!7_(`J8_W@`".]ZFT(`>__PO@```09X`"$@`.F5(``$A2``Y78`!`!1\"`.F
M@\$`"#@A`!!.@``@`````'PI"WA4(0`V.````)0A__!\"`.FD`$``#T`$`"%
MJ%G82``Z\````````````````)0A_^!\"`*FDX$`$).A`!0_@!`"D`$`))/!
M`!B3X0`<B!S!A"^```!`G@!D/^`0`C^@$`(_P!`".[V^V#O>OMQ_W?!0@3_!
MB'_>%G`[WO__?XGP0$"<`#`[_\&(8````#DI``%5(!`ZD3\``'P=`"Y\"0.F
M3H`$(8$_``!_B?!`09S_X#@```&8',&$@`$`)(.!`!"#H0`4@\$`&'P(`Z:#
MX0`<."$`($Z``"!@````E"'_\'P(`J:0`0`4@`$`%#@A`!!\"`.F3H``(&``
M```](!`"E"'_\'P(`J8X:;[@D`$`%(`)ON`O@```09X`'#T@```X"0``+X``
M`$&>``Q\"0.F3H`$(8`!`!0X(0`0?`@#IDZ``"!@````8````)0A__!\"`*F
MD`$`%(`!`!0X(0`0?`@#IDZ``"``````E"'_\'QJ&WB(`P``+X```$&>`$P]
M8!``.2,``8%K6>R):P``2```'&````!@````B`D``#DI``$O@```09X`('^`
M6`!`GO_LB`D``'TJ2W@Y*0`!+X```$">_^A]0U-X."$`$$Z``"!@````8```
M`)0A_J`X```0?`D#ICE#`!PY(```DX$!4).A`523P0%8D^$!7#EA`!!@````
M8````'P*2"Y\"TDN.2D`!$(`__0Y(0!$.0$!1&````!@````@6G_[(`)``"!
M2?_4?6`">(%I_\Q\`%)X?`!:>%0`"#Z0"0`,.2D`!'^)0`!`GO_4@(,`$(/!
M`!"``P``@,,`!(#C``B`HP`,?\3R%($!`!2!@0`8/]Y:@E3*\#Y4'R@^?*LP
M>(.!`!Q]!4(4?.DP.#O>>9E]:4MX?][Z%'U+`#A\_P!X/0A:@GT^2A1_ZUMX
M.0AYF7V'8A1]"%H452LH/GUH6A0]C%J"5`CP/E4^\#Y]7TAX57TH/GTI0#@Y
MC'F9?8SJ%'_I2W@_G%J"?2Q*%(&!`"!]'5AX?7_P.#N<>9E_O_MX?5Q2%#V,
M6H*#@0`D?^KZ%%4J*#Y]7U(4.8QYF55_\#Y572@^?\M(>'V,0A15*/`^?2GX
M.'V,ZA1]:4MX/YQ:@GTL2A2!@0`H?_U0>'U+0#@[G'F9?ZM;>'_<\A0]C%J"
M@X$`+'_>6A15*R@^?7Y:%#F,>9E57O`^57TH/GT*2'A]C/H453_P/GTI\#A]
MC.H4?4E+>#^<6H)]+$H4@8$`,'_=6'A]:O@X.YQYF7^J4WA]'$(4/8Q:@H.!
M`#1]"%(452HH/GU(4A0YC'F956CP/E5=*#Y_ZTAX?8SR%%4^\#Y]*4`X?8SJ
M%'UI2W@_G%J"?2Q*%(&!`#A]'5!X?4OP.#N<>9E_JUMX?_SZ%#V,6H*#@0`\
M?_]:%%4K*#Y]?UH4.8QYF55?\#Y5?2@^?\I(>'V,0A15*/`^?2GX.'V,ZA1]
M24MX/YQ:@GTL2A2!@0!`?_U8>'UJ0#@[G'F9?ZI3>'_<\A0]C%J"@X$`1'_>
M4A15*B@^?5Y2%#F,>9E5?O`^55TH/GT+2'A]C/H453_P/GTI\#A]C.H4?6E+
M>#^<6H)]+$H4@8$`2'_=4'A]2_@X.YQYF7^K6WA]'$(4/8Q:@H.!`$Q]"%H4
M52LH/GUH6A0YC'F954CP/E5]*#Y_ZDAX?8SR%%4^\#Y]*4`X?8SJ%'U)2W@_
MG%J"?2Q*%(&!`%!]'5AX?6KP.#N<>9E_JE-X?_SZ%#V,6H*#@0!4?_]2%%4J
M*#Y]7U(4.8QYF55_\#Y572@^?\M(>'V,0A15*/`^?2GX.'V,ZA1]:TMX/YQ:
M@GUL6A2!@0!8?_U0>'U)0#@[G'F9?ZE+>'_<\A0]C%J"@X$`7'_>2A15:2@^
M?3Y*%%5*\#XYC'F953TH/GT>6'A]C/H457_P/GUK4#A]C.H4?]Y;>'U=2'A]
M*_@X?[U;>#^<6H*!80!@.YQYF7_,\A2!@0"H?1Q"%#UK;MI_B.H4.0OKH5?+
M*#Y5*?`^?7Q:%(.!`&1]/?IX?4A2%%?(\#X_G&[:?[[R>'^J\A0[G.NA?1Y*
M>%5J*#Y]75(4?YSZ%(.A`&A5?_`^?\M:>'^<6A152R@^?7Q:%#^];MJ#@0!L
M?_Y">#N]ZZ%_O4H4/YQNVE5)\#Y_RE)X?[U2%'T^^GA5:B@^.YSKH7U=4A1_
MG$(4@Z$`<%5H\#Y_RUIX?YQ:%%5+*#Y]?%H4/[UNVH.!`'1]'DIX.[WKH7^]
M^A0_G&[:55_P/G_*4GA_O5(4?_Y">%5J*#X[G.NA?5U2%'^<2A2#H0!X56GP
M/G_+6GA_G%H454LH/GU\6A0_O6[:@X$`?'T^^G@[O>NA?[U"%#^<;MI52/`^
M?\I2>'^]4A1]'DIX56HH/CN<ZZ%]75(4?YSZ%(.A`(!5?_`^?\M:>'^<6A15
M2R@^?7Q:%#^];MJ#@0"$?_Y">#N]ZZ%_O4H4/YQNVE5)\#Y_RE)X?[U2%'T^
M^GA5:B@^.YSKH7U=4A1_G$(4@Z$`B%5H\#Y_RUIX?YQ:%%5+*#Y]?%H4/[UN
MVH.!`(Q]'DIX.[WKH7^]^A0_G&[:55_P/G_*4GA_O5(4?_Y">%5J*#X[G.NA
M?5U2%'^<2A2#H0"056GP/G_+6GA_G%H454LH/GU\6A0_O6[:@X$`E'T^^G@[
MO>NA?[U"%#^<;MI52/`^?\I2>'^]4A1]'DIX56HH/CN<ZZ%]75(4?YSZ%(.A
M`)A5?_`^?\M:>'^<6A152R@^?7Q:%#^];MJ#@0"<.[WKH7_^0GA_O4H4/YQN
MVE5)\#X[G.NA?\I2>'T^^GA_O5(4?YQ"%%5J*#Y5:/`^?\M:>(/!`*!]75(4
M?1U*>'^<6A0_WF[:54LH/CO>ZZ%]?%H4?_[Z%%5>\#Y_JE)X@Z$`I#V,;MI_
MGU(4?]]">#^];MI5:B@^.[WKH7U<4A2#@0"L?[U*%%5I\#Y_ZUIX.8SKH7T_
M\GA_O5H454LH/GV,0A1]?5H454CP/G_J4GA5?R@^?8Q2%'T=2GA_[/H4@8$`
ML#^<;MI5:O`^.YSKH3V,CQQ_JUIX.8R\W'U=0#A]+$H4@8$`M'_<\A1]7$-X
M?]Y:%#V,CQQ7Z_`^.8R\W'^<^#A]#$(4@8$`N%?_*#Y_WOH4?Y_K>#V,CQQ]
M?5`X.8R\W'U\4WA]3%(4@8$`O'^<\#A_Z?H45\GP/CV,CQQ7WB@^.8R\W'__
M\A1_GNMX?3U8.'T\6WA];%H4@8$`P'^<^#A_R/(4/8R/'%?H\#XYC+S<5_\H
M/G_>^A1_G^MX?1U(.'T<2WA]+$H4@8$`Q'^<\#A_ZOH45\KP/CV,CQQ7WB@^
M.8R\W'__\A1_GNMX?5U`.'U<0WA]#$(4@8$`R'^<^#A_R_(4/8R/'%?K\#XY
MC+S<5_\H/G_>^A1_G^MX?7U0.'U\4WA]3%(4@8$`S'^<\#A_Z?H45\GP/CV,
MCQQ7WB@^.8R\W'__\A1_GNMX?3U8.'T\6WA];%H4@8$`T'^<^#A_R/(4/8R/
M'%?H\#XYC+S<5_\H/G_>^A1_G^MX?1U(.'T<2WA]+$H4@8$`U'^<\#A_ZOH4
M5\KP/CV,CQQ7WB@^.8R\W'__\A1_GNMX?5U`.'U<0WA]#$(4@8$`V'^<^#A_
MR_(4/8R/'%?K\#XYC+S<5_\H/G_>^A1_G^MX?7U0.'U\4WA]3%(4@8$`W'^<
M\#A_Z?H45\GP/CV,CQQ7WB@^.8R\W'__\A1_GNMX?3U8.'T\6WA];%H4@8$`
MX'^<^#A_R/(4/8R/'%?H\#XYC+S<5_\H/G_>^A1_G^MX?1U(.'T<2WA]+$H4
M@8$`Y'^<\#A_ZOH45\KP/CV,CQQ7WB@^.8R\W'__\A1_GNMX?5U`.'U<0WA]
M#$(4@8$`Z'^<^#A_R_(4/8R/'%?K\#XYC+S<5_\H/G_>^A1_G^MX?7U0.'U\
M4WA]3%(4@8$`['^<\#A_Z?H45\GP/CV,CQQ7WB@^.8R\W'__\A1_GNMX?3U8
M.'T\6WA];%H4@8$`\'^<^#A_R/(4/8R/'%?H\#XYC+S<5_\H/G_>^A1_G^MX
M?1U(.'T<2WA]+$H4@8$`]'^<\#A_ZOH45\KP/CV,CQQ7WB@^.8R\W'__\A1_
MGNMX?5U`.'U<0WA]#$(4@8$`^'^<^#A_R_(45^OP/E?_*#Y_WOH4/8R/''^?
MZWA]?%-X?7U0.'^<\#A_Z?H4.8R\W%?)\#Y7WB@^?__R%'U,4A2!@0#\?Y[K
M>'T\6WA]/5@X?YSX.'_(\A17Z/`^5_\H/CV,CQQ_WOH4?Y_K>'T=2WA_BOH4
M?[WP.'T?2#@YC+S<5\HH/GU<4A1_O_MX@Z$!`%?>\#Y];%H4?8OZ%'_?0GA5
M2R@^?_]2>'UL6A0_O<IC54SP/H%!`00[O<'6?3U*%#U*RF-_J?H4.4K!UGV)
M\GA5?R@^?0I"%'_]^A15:O`^?2M:>($A`0A_J%H45^LH/GU]6A0]*<IC@Z$!
M#'U(8G@Y*<'6?\GR%#^]RF-7Z?`^?1_Z>'_>^A15:"@^?3]2>#N]P=9]'D(4
M?[UB%(/!`1!5;/`^?^M:>'^]6A15"R@^?7U:%#_>RF.#H0$4?9]*>#O>P=9_
MWE(4/[W*8U4*\#Y_Z$)X?]Y"%'U?8GA5:"@^.[W!UGT>0A1_O4H4@\$!&%5I
M\#Y_ZUIX?[U:%%4+*#Y]?5H4/][*8X.A`1Q]/U)X.][!UG_>8A0_O<IC50SP
M/G_H0GA_WD(4?9]*>%5H*#X[O<'6?1Y"%'^]4A2#P0$@56KP/G_K6GA_O5H4
M50LH/GU]6A0_WLIC@Z$!)'U?8G@[WL'6?]Y*%#^]RF-5"?`^?^A">'_>0A1]
M/U)X56@H/CN]P=9]'D(4?[UB%(/!`2A5;/`^?^M:>'^]6A15"R@^?7U:%#_>
MRF.#H0$L?9]*>#O>P=9_WE(4/[W*8U4*\#Y_Z$)X?]Y"%'U?8GA5:"@^.[W!
MUGT>0A1_O4H4@\$!,%5I\#Y_ZUIX?[U:%%4+*#Y]?5H4/][*8X.A`31]/U)X
M.][!UG_>8A0_O<IC50SP/G_H0GA_WD(4?9]*>%5H*#X[O<'6?1Y"%'^]4A2#
MP0$X56KP/G_K6GA_O5H450LH/GU]6A0_WLIC@Z$!/'U?8G@[WL'6?]Y*%#^]
MRF-5"?`^?^A">'_>0A1]/U)X56@H/CN]P=9]'D(4?[UB%(/!`4!5;/`^?^M:
M>'^]6A15"R@^?7U:%#_>RF.#H0%$.][!UGV?2GA_WE(4/[W*8U4*\#X[O<'6
M?^A">'U?8GA_WD(4?[U*%%5H*#Y5:?`^?^M:>(/A`4A]'D(4@\$!3'^]6A15
M"R@^/__*8W_`\A0[_\'6?2!2>'U]6A1]GV(4/][*8U4?\#Y\"$)X.][!UGV,
M0A158"@^?^A*>'U>4A1\#`(4?0A:>'T*0A15:_`^5`HH/GRE^A1]2%(4?`8"
M%'SG6A1])$H4D4,``)`#``2#@0%0@Z$!5)#C``B0HP`,@\$!6(/A`5PX(0%@
MD2,`$$Z``"!@````8````&````"4(?_0?`@"II.!`""380`<?'P;>9-!`!B0
M`0`T?)HC>).A`"23P0`HD^$`+$""`#0X8```@`$`-(-!`!B#80`<@X$`('P(
M`Z:#H0`D@\$`*(/A`"PX(0`P3H``(&`````](!`"@VG!8"^;``!!GO_$B!P`
M`"^```!!G@"8+X``/4&>`)!_G>-XC!T``2^````O```]09X`"$":__!_O.A0
M@_L``"^?``!!GO^(?W[;>'_C^WA_A.-X?Z7K>$@`+/4O@P``0)X`$'P?Z*XO
M@``]09X`((?^``0OGP``0)[_U$O__U!@````8````&````!_V_!0.'T``7_>
M%G"3V@``?'\:%$O__S!@````8````#N@``!+__^,8````&````"4(?_@?`@"
MII`!`"0X@0`<3,8Q@DO__LV``0`D."$`('P(`Z9.@``@8````&````"4(?_@
M?`@"II/A`!R0`0`D/^`0`H!_P4PO@___09X`)(`!`"2#X0`<."$`('P(`Z9.
M@``@8````&````!@````/&`0`#AC6GA,QC&"2___A2P#``!!@@`\B&,``"^#
M``!!G@`P:&,`,'QC`-!48P_^D'_!3(`!`"2#X0`<."$`('P(`Z9.@``@8```
M`&`````X8```D'_!3$O__]Q@````E"'_T'P(`J:3H0`DD\$`*#^@$`)\?AMX
MD^$`+)`!`#0[O<%@.^$`'$@``"A@````@2$`'(`=``!5*1`Z?2!*%(0)``20
M"?_\+X```$">__1_P_-X?^3[>$S&,8)+__VU+X,``$">_\R``0`T@Z$`)(/!
M`"B#X0`L."$`,'P(`Z9.@``@8````&````!@````E"'OT#Q@$`!\"`*F.&-:
MA).!$""3H1`D?+PK>'R=(WB3P1`HD^$0+#B@#_^0`1`T.\$`''_$\WB``H_X
MD`$0'#@```!(`"I]?'\;>4"!`+@X'___.6$0('TK`A2)*>_\+XD``$&>`'Q_
MP_-X.(``+W_E^WA(`"JM+X,``$&>`(@X8```2``K#8!C``!(`"?U?Z3K>'_%
M\WA_YOMX2``I18`!$!R!(H_X?`!*>3D@``!`@@!T@`$0-(.!$""#H1`D@\$0
M*'P(`Z:#X1`L."$0,$Z``"!@````8````&`````O@```09X`('P?`WA_P_-X
M.(``+W_E^WA(`"HI+X,``$">_X`X8```2``JB8!C``!(`"=Q?Z3K>'^%XWA(
M`"<U2___@$@`*4U@````8````)0A__`X8```?`@"II`!`!1(`"I1@&,``$@`
M)SDX@/__2``G@3A@``!(`"HY@&,``$@`)R$\@!``.*```#B$+:!(`"J!@`$`
M%#@A`!!\"`.F3H``(&````!@````8````)0A_^`X8```?`@"II/A`!R0`0`D
M2``I[8!C``!(`";52``E<8$C```X8```@^D`!$@`*=&`8P``2``FN4@`)@6(
M`P``.&```)@?`!A(`"FU@&,``$@`)IU(`"4Y@2,``#A@``"#Z0`$2``IF8!C
M``!(`":!2``EW8$C```X8```@`D`$%0`3?ZP'P`:2``I=8!C``!(`"9=2``D
M^8$C```X8```@^D`!$@`*5F`8P``2``F03R`$``XH```.(1;L$@`*,&0?P`<
M.&```$@`*36`8P``2``F'4@`)+F!(P``.&```(/I``1(`"D9@&,``$@`)@%(
M`"4M@`,``#A@``"0'P`@2``H_8!C``!(`"7E2``D@8$C```X8```@^D`!$@`
M*.&`8P``2``ER4@`)^4X````@2,``"^)``!!G@`@.&```$@`*+V`8P``2``E
MI4@`)\&!(P``@`D`;)`?`"0X8```.^```$@`*)F`8P``2``E@4@`)!V!(P``
M.&```($I``23Z0`H2``H>8!C``!(`"5A2``C_8$C```X8```@2D`!)/I`"Q(
M`"A9@&,``$@`)4%(`"/=@2,``#A@``"#Z0`$2``H/8!C``!(`"4E2``G\8`#
M``"0'P`P@`$`)(/A`!PX(0`@?`@#IDZ``""4(?]@?`@"II/A`)R3P0"8?'\;
M>9`!`*2380",DX$`D).A`)1!@@`0B!\``"^```!`G@`P@`$`I(-A`(R#@0"0
M@Z$`E'P(`Z:#P0"8@^$`G#@A`*!.@``@8````&````!(`"4Q?'X;>4&"_\P_
M8!``.X$`&#M[6I1@````8````'_#\WA(`"5]?&@;>7_C^WA!@@"PB`@`$SD(
M`!,O@``N09X`X)$!``Q(`"6)@0$`#'Q]&WA]`T-X2``E>7Q]&A0X8P`"2``F
M#8$!``Q_9MMX?^?[>#B```$XH/__?'T;>$S&,8)(`";]?X7C>'^DZW@X8``#
M2``C32^#__]_H^MX09X`%(`!`"A4``0F+X!``$&>`*!(`"4M?Z/K>$@`)"5_
MP_-X2``DW7QH&WE_X_MX0(+_9&````!@````8````'_#\WA(`"5-?^/[>$@`
M);6``0"D@V$`C(.!`)"#H0"4?`@#IH/!`)B#X0"<."$`H$Z``"!@````8```
M`&````"("``!+X```$&>_O@O@``N0)[_%(@(``(O@```09[^Y$O__P1@````
M8````&````!+__Y12___9&````!@````E"'_X'P(`J:3X0`<D`$`)'Q_&W@X
M8```2``F.8!C``!(`",A2``E37_D^WA\91MX.&```T@`(VTO@P``09X`)(`!
M`"2#X0`<.&```#@A`"!\"`.F3H``(&````!@````2``E\8!C``!(`"+92``E
M!8`#`!!4``0F+X!``$&>`"PX8```2``ES8!C``!(`"*U2``DX8$C`!!5*00F
M;2#__R^`H`!`GO^<?^/[>#B```)(`",!@`$`)(/A`!PX(0`@?`@#IGQC`#14
M8]E^3H``()0AW]!\"`*FD^$@+)/!("B0`2`TDZ$@)#OA$!N``H_XD`$@'#@`
M``!(`"#Y/,`0`#T`$`!\9QMX.,9:G#D(6JA_X_MX.(```3B@$`%,QC&"2``E
M`2^#``!`G`!(.^```($A(!R``H_X?2D">3@```!_X_MX0((`<(`!(#2#H2`D
M@\$@*(/A("PX(2`P?`@#IDZ``"!@````8````&`````[P0`:?^/[>'_$\W@X
MH!``2``D`7Q]&WE!@/^D.'T``4@`(X%\?QMY08+_F'_$\WA_I>MX2``BK3@`
M``!\'^FN2___@$@`(WU@````8````)0A__`X(0`02___"&````"4(?_`?`@"
MII.!`#"3H0`T?'T;>)/!`#B3X0`\D`$`1),A`"2300`HDV$`+(@$``!H'P`]
M(_\``'_D`91_X_MX2``B83B!`!Q\?!MX?Z/K>$S&,8)+__8=?'X;>4&"`&1(
M`")!.2```'^<&$!!G0(`?!](KGP>2:XY*0`!+X```$">__"``0!$@R$`)#A@
M``"#00`H@V$`+'P(`Z:#@0`P@Z$`-(/!`#B#X0`\."$`0$Z``"!@````8```
M`&`````_8!`".\```#B```B`>\%@?&D;>(`#```O@```09X`'(0)``0[W@`!
M+X```$">__0XG@`"5(00.CT@$`*`"<&,+X```$&>`$Q(`!^)5]D0.B^#``!\
M>AMXD'O!8$">`&"``0!$@R$`)#A@__^#00`H@V$`+'P(`Z:#@0`P@Z$`-(/!
M`#B#X0`\."$`0$Z``"`X```!?(,C>)`)P8Q(`"'E?'H;>4&"_[Q7V1`Z@)O!
M8'\ERWA(`")-DUO!8#@>``$Y(```5``0.GTZ`2Z3P0`<B!T``"^```!!G@#D
M+X``/4&>`-Q_J>MX2```#&````!!F@`4C`D``2^````O```]0)[_\'T]2%`X
M?``"@]O!8'QC2A1(`"%M+X,``'Q^R2Y!GO]`/2`0`H@=```O@```@6G!8($A
M`!Q5*1`Z?2M(+I@)``!!G@`X+X``/4&>`#`[O0`!2```$&````!@````09H`
M'(@=```[O0`!G`D``2^````O```]0)[_Z#@``#TY8```F`D``&````!@````
M?!]8KGU)6A0Y:P`!+X```)@*``%`GO_L2__^'(,A`!P_8!`"5SD0.DO__Q@Y
M(```2___2&````!@````8````#T@$`"4(?^P.2E9['P(`J:3X0!,D\$`2)`!
M`%23H0!$?'T;>(/I``2`"0`8DP$`,),A`#2`Z0`(@0D`#)-!`#B380`\@4D`
M$(%I`!23@0!`D.$`')$!`""100`DD6$`*)`!`"R3X0`8B!\``"^```!!G@"(
M/V`0`(.)`!P[P0`<.WM:K$@``"Q@````8````$@`(!$O@P``09X`F(/^```[
MW@`$B!\``"^```!!G@!,?^/[>$S&,8)+__1)?Z3K>'QY&WE!@@`0B!D``"^`
M``!`GO_`?^/[>'^DZWA,QC&"2__\D8/^```[W@`$B!\``"^```!`GO^\@`$`
M5(,!`#"#(0`T@T$`.'P(`Z:#80`\@X$`0(.A`$2#P0!(@^$`3#@A`%!.@``@
M8````&````!_H^MX2``>W7QX&WA_@^-X2``>T7QZ&WA_(\MX2``>Q7TXTA0X
M"0`"?&`:%$@`'U5_*<MX.(```3B@__]_9MMX?'H;>'^GZWA_B.-X3,8Q@D@`
M($%_X_MX?T33>$S&,8)+__OA2___"&````!@````E"'_L#R`$`!\"`*F.(19
M[#B@`"*3@0!`DZ$`1#B$`"`_H!``D\$`2)/A`$P_X!``.[U:^)`!`%0[_UK<
M/\`0`#O>6G@_@!``.YQ;!#AA`!J``H_XD`$`/#@```!(`!WU/&`0`#AC6K1,
MQC&"2__SQ3Q@$``X8UK`3,8Q@DO_\[4\8!``.&-:R$S&,8)+__.E/&`0`#AC
M6M1,QC&"2__SE7_C^WA,QC&"2__SB3Q@$``X8UKL3,8Q@DO_\WE_H^MX3,8Q
M@DO_\VU_P_-X3,8Q@DO_\V%_@^-X3,8Q@DO_\U4\8!``.&-;$$S&,8)+__-%
M/&`0`#AC6QQ,QC&"2__S-3Q@$``X8ULL3,8Q@DO_\R4\8!``.&-;.$S&,8)+
M__,5/&`0`#AC6T1,QC&"2__R-7QD&WE!@@`0?X/C>$S&,8)+__J1/&`0`#AC
M6UA,QC&"2__R$7QD&WE!@@`4/&`0`#AC6VQ,QC&"2__Z:3Q@$``X8UMX3,8Q
M@DO_\>E\9!MY08(`8'^CZWA,QC&"2__Z13R`$`!_X_MX.(1;J$S&,8)+__HQ
M@2$`/(`"C_A]*0)Y.````$""`(R``0!4@X$`0(.A`$2#P0!(?`@#IH/A`$PX
M(0!03H``(&````!@````/&`0`#AC6XA,QC&"2__Q=7QD&WE!@@`<?\/S>$S&
M,8)+__G12___C&````!@````/(`0`#AA`"LXA%N<.*``"D@`'=$O@P``0)[_
M:'_#\W@X@0`U3,8Q@DO_^9E+__]42``<\6````!@````8````)0A__!\"`*F
MD`$`%$@`'%5(`!PQ.````"P#``!!@@`(@`,``'P#`WB``0`4."$`$'P(`Z9.
M@``@8````&````"4(?_@?`@"II/!`!B3X0`<?'X;>9`!`"1!@@"XB!X``"^`
M``!!G@"L2``;N3U`$``X`___?+X"%'^>*$!`G`!(@2I9['U^`*Z)*0``?XM(
M`$">`,!\?AH4?!XH4#AC__Y_GAA`?`D#ID"]`!1(``&0B`4``'^`6`!`G@"8
M.*7__T(`__!_A?``0)X`Q(!J6>R))0``B`,``'^)``!!G@$D2``=87Q_&WB`
M`0`D@\$`&'_C^WB#X0`<."$`('P(`Z9.@``@8````&````!@````.&```D@`
M&ZU\?QMY08+_S#@`+@!_X_MXL!\``(`!`"2#P0`8@^$`'#@A`"!\"`.F3H``
M(&````!@````8````#@%__]_G@!`?!XH4'P)`Z9!G0#0+Y[__T"^`!1(``#$
MB`4``'^`2`!!GO],.*7__T(`__!_A?``09[_1#@%__^!:EGL?YX`0'P>*%!\
M"0.F09T`A"^>__]!G@!\8````#BE__]"0``4B`L``(DE``!_B0``09[_['R^
M*%`[X```.`4``BN`$`!!G?\0/^`0`G_$\W@[_\&,.*4``3O_``0XP!``?^/[
M>$@`%]E+__[L.&```CO@``!(`!JY+`,``$&"_M@X`"X`?'\;>+`#``!+__[(
M.````7P)`Z9+__^$.````7P)`Z9+__]$.````7P)`Z9+__YX8````&````"4
M(?_@?`@"II/!`!B3X0`<?'X;>)`!`"1+__W9B`,``'Q_&W@O@```09X`1#T@
M$``X8P`!@2E9[(DI``!(```4B`,``#AC``$O@```09X`('^`2`!`GO_LB`,`
M`'Q_&W@X8P`!+X```$">_^A+_^Z%+X,``$&>`#`OG@``09X`*(@>```O@```
M09X`'#R`$`!_X_MX.(1;K$@`&<E_GQ@`09X`'(`!`"2#P0`8@^$`'#@A`"!\
M"`.F3H``((`!`"2#X0`<?\/S>(/!`!@X(0`@?`@#IDO_\LQ@````8````)0A
M_]!\"`*FD&$`')"!`!B0H0`4D`$`-)/A`"R3P0`H.&$`'#B!`!@XH0`42``:
ME3R`$``\8!``.(13D#AC56!\A2-X2``4;3A@``!(`!>EB^,``"^?``!`G@`T
M2``7A3T@$`(O@P``D&G1D$&>`D!(`!A!.&```$@`&EF`8P``2``704@`&:V;
MXP``.&```$@`&D&`8P``2``7*4@`&D5\:1MX.&```(@)``!@```"F`D``$@`
M&AV`8P``2``7!4@`&B$](!``P`E:9#T@$`"(`P``8````9@#```\`$,PD`$`
M"(!A`!PX8P`%D&$`#,FA``C]K0`HR`E::#T@$`#]K0`JR`E:</^-``!!G0&(
M/^`0`E1C$#H[_\&,2``9)8$!`!B`H0`</6`0`"^%``%\:1MXD'\0"(`(``"0
M`P``.`M;M#U@$`"0`P`$.`M=;#U@$`"0`P`(.`M;N)`#``PX```$D!\0#$"=
M`"PX!?__.6``!'P)`Z9@````8````'U)6A1\"%@N.6L`!)`*``Q"`/_P.*4`
M`SE@``"`?Q`$5*`0.CR`$`!])DMX.(11$#C@``!]:0$N2``4^7Q^&WE!@@!0
M@'\0!$@`%ZD\8!``.&-:[$S&,8)+_^P)+X,``$&>`%R`?Q`$2``4J4@`%G6`
M`0`T@^$`+'_#\WB#P0`H."$`,'P(`Z9.@``@8````(!_$`1(`!4]?'X;>(!_
M$`1(`!=1/&`0`#AC6NQ,QC&"2__KL2^#``!`GO^L@'\0$"^#``!!G@`P2__\
MV8!_$`1(`!1!2``6#8`!`#2#X0`L?\/S>(/!`"@X(0`P?`@#IDZ``"`\8!``
M.&-:^$S&,8)+_^MA+X,``)!_$!!!GO]82___N#Q@$``\@!`".&-;Z#B$P7!,
MQC&"2``7>3A@``%(`!AQ8````&````!@````?8``)I0A[[!\"`*FDV$0/).!
M$$"3H1!$D\$02'Q]&W@\8!``D^$03)&!$"`X8UKX?)XC>)`!$%22H1`DDL$0
M*)+A$"R3`1`PDR$0-)-!$#B``H_XD`$0'#@```!,QC&"2__JP3T@$``[B5GL
M?'L;>(/I6>Q_H^MX?^3[>$@`%D4O@P``09X`=#Q@$`!_I.MX.&-;'$S&,8)+
M__+Y@2$0'(`"C_A]*0)Y.````'^CZWA`@@'<@`$05(&!$"""H1`D@L$0*'P(
M`Z:"X1`L@P$0,'V`@2"#(1`T@T$0.(-A$#R#@1!`@Z$01(/!$$B#X1!,."$0
M4$Z``"!_H^MX2``5-8-<`!Q\>1MX?T33>'_#\WA(`!8!?'4;>4&"_W`^X!``
M/P`0`#K````Z]UN\.SD``3L86JQBUH``+AL``#N!`!P[P```8````&````!@
M````B!4``"^```!`G@`(?O6[>$&2`!A_8]MX?J2K>$@`%L4O@P``09X`R'ZC
MJWA(`!2UB!\``'TU&A2):?__?XL``$">`"Q@````8````&````";R?__B`G_
M_CAC__\Y*?__B7\``'^+``!!GO_H?'D:%"^##_]!G?[$?J>K>#B```$XH!``
M?P;#>'_H^WA_J>MX?X/C>$S&,8)(`!7Y.&```$@`%B&`8P``2``3"4@`%35_
MA.-X?&4;>#A@``-(`!(U+X,``$">`"1(`!7Y@&,``$@`$N%(`!4-@`,`$%0`
M!"9_@+``09X`(#A@``!_1--X2``4T2^#``!\=1MX0)[_!$O__CA_@^-X.(``
M`4@`$Q4O@P``0)[_U#Q@$`!_A.-X.&-;'$S&,8)+__$9?X/C>$@`%=%\?1MX
M2__^%$@`%&4\`/__?"P+>&``?M!\(0%N?`@"II`,``23C/_P/X`0`'P``"8Y
M/%GLD^S__)/,__@[X8#PDBS_Q)),_\@^(0`!DTS_Z)-L_^R`J0!T@VD`2).L
M__23+/_D/R`0`(/)`%"`R0!4.SE:^)`,_\"2;/_,@.D`6($)`%R!20!@@6D`
M9)*,_]"2K/_4@`D`:(")`&R#20!$@ZD`3)+,_]B2[/_<@2D`<),,_^""0H_X
MDE&`[#I```"3?W]$DU]_0'Q[&WB3WW],D[]_2'\CRWB0GW]0D3]_5)"_?UB0
MWW\HD/]_+)$??S"17W\TD7]_.)`??SQ,QC&"2__GG7Q^&WE!@@`0B!X``"^`
M``!`G@>X2__V=2X#``!\>AMX09('V(O:```OG@``09X`0$@`$?E_2=-X.4``
M7V````!@````8````(%C``!7W@@\?`OR+G`3"`!`@@`(F4D``(_)``$OG@``
M0)[_X(!_?RB(`P``+X```$&>!J`[WW\L2```'&````"`?@``.]X`!(@#```O
M@```09X&@$S&,8)+_^;Y?'T;>4&"_^!+_^V-+X,``$&>_]1_H^MX2``4#7QX
M&WE!@O_$?P/#>$@`$=U\?1MX?T/3>$@`$=%_O1H4.[T$!'^CZWA(`!)A?'X;
M>'^CZWA(`!)5@YQ9[#S`$``](!``?P?#>#C&6\`Y*5NL?TK3>#B@__]_B.-X
M?'T;>#B```%,QC&"2``3,3B``>U_H^MX2``/!3Q@$`!_V/-X.&-=4$S&,8)+
M_^91+X,``$&>!IB#6P``2``3<7QD&WA_0]-X2__[%7QZ&WE!@@9\?T/3>$@`
M$34O@P`#?'<;>$"=`$@X8__\/(`0`'QZ&A0XA%O,2``3%2^#``!`G@`L+Y<`
M!$&>!=1^^KH4B!P``(DW__M_B0``09X%P&````!@````8````'];TWA+_^7]
M+X,``$&>`50\@!``/&`0`#B$6Z@X8UIX3,8Q@DO_[AT_8!``/T`0`$@`#C$[
M>UNP/,`0`#C&6_0X@``!?&D;>#B@__]_P_-X?Z?K>'^(XWA_:MMX3,8Q@D@`
M$C$[6EP$.^```$@``$A(``W1@`,``"^``!%`G@!,2``-X3O_``$X@``!DV$`
M"#B@__]_1M-X?&D;>'^GZWA_P_-X?XCC>'_J^WA,QC&"2``1X7_#\W@X@`'M
M2``-M2^#__]!GO^L?Z/K>$@`#R5_(\MX?\3S>$S&,8)+_^UE?\/S>$O_[^T\
MP0`!?P/#>(#F@.R`PH_X?.<R>3C```!`@@9$@6$``(`+``2!B__`@BO_Q()+
M_\A\"`.F@FO_S(*+_]!]@($@@JO_U(++_]B"Z__<@PO_X(,K_^2#2__H@VO_
M[(.+__"#J__T@\O_^(/K__Q]85MX3H``(&````!_8]MX.(```$S&,8)(`!$%
M?'H;>4&"_IPXH/__.,#_[CC@``([?W]<2``-J7]#TWA_9-MX.*``!D@`#BF(
M'W]<+X```$">`!"('W]=+X``0T&>!0P^X0`!.,```']#TW@XH```..```#O_
M?UQ(``UE/2!G13@```!A*2,!D!>`8)`7@&0XP```D3>`3)`7@*@](._-.```
M`&$IJXE@`(!,D3>`4#T@F+I@QH!H82G<_G[!`A21-X!4/2`0,F$I5':1-X!8
M/2##TF$IX?"1-X!<?N$R%&````!@````8````#B@``!_0]-X8*6``'_D^WA(
M``UQ?'L;>4"!`20\X0`!5V`8.($G@&!\`$H4?XD`0$&=`X"!)X!D/6$``3XA
M``%_]/MX@&N`J%=K'WY]*5H4D!&`8"^#``"1,8!D09X`5"`#`$!_=-MX?YL`
M`$"=``A\%`-X/D$``7QW&A1_Y/MX?H6C>$@`#?V`$H"H?!0"%"^``$"0$H"H
M0)[_:'[#LWA_=-A0?I^B%$O_TWE@````+YL`/T"=`%`ZH```8````'R4JA0X
MH`!`?N.[>#JU`$!(``VQ?L.S>$O_TTE\%=A0+X``/T&=_]P[>__`5VG1OC@)
M``%5*3`R5``P,GZ4`A1_:=A0/F$``7]EVWA^A*-X.,``1'[CNWA(``Q)DW.`
MJ#B@``!_0]-X8*6``'_D^WA(``Q1?'L;>4&!_N1_0]-X2``-T3S!``$XX```
M8.>`\'SG"A2#YH!@@V:`9%?I[KY]9TH4.`D``2^``#@Y(/^`F2O_>$&=`MQ\
M=P(4(*``.#B```!(``NM/B$``3Y!``%79T8^5VB$/E=JPCY7ZT8^5^F$/E?@
MPCY^P[-XF/&`H)D1@*&948"BFW&`HYEQ@*29,8"EF!&`IIOQ@*=+_])5/B$`
M`8%2@%"!<H!4@3*`6(`2@%R!$H!,57>$/E4_A#Y5$H0^51/"/II1@-F:<8#:
M.D```#I@``!B4H"O579&/E5ZPCY5.T8^50=&/E5,1CY55(0^557"/E4CPCY4
M!$8^5`6$/E0&PCZ:\8#AFM&`X#[@$`!B<X#8F_&`Y9MQ@.1_X9(4.O=;[)M1
M@.*9<8#C?_K[>#M@``"9$8#;F9&`W'[!FA2:D8#=FK&`WIE1@-^8<8#FF3&`
MYYB1@.B8L8#IF-&`ZI@1@.N8\8#82```"'SVV*Y_0]-X.(```3B@__]^YKMX
M3,8Q@D@`#9DOFP`3.UH``CM[``%`GO_8/N$``3@````\P!``/4`0`#C&6]Q_
MB.-XF!>`UW_I^W@Y2ENP?\/S>#B```$XH/__?Z?K>$S&,8)(``U-2__[@&``
M``"#WW]`.[]_1#L```"('@``+X```$">`"!+__F88````(/=```[O0`$B!X`
M`"^```!!GOF`?\/S>#L```!+_^;E+X,``$&>_]Q_P_-X2``-97QX&WE!@O_,
M2__Y6&````"#>P`$+YL``$&>^DA_8]MX2``+(2N#``-`G?HX.&/__#R`$`!\
M>QH4.(1;U$@`#04O@P``09[Z($O_^AA@````/4$``8$J@&0Y*0`!2__\?$O_
MZM%_P_-X2``,^7QX&WA+__K88````&````!@````@UL``$O_^81@````8```
M`(!_?U"(`P``+X```$&>`$@[WW]48````&````!@````3,8Q@DO_WWTO@P``
M09X`$$@`#*%\>AMX+@,``$"2]_"`?@``.]X`!(@#```O@```0)[_T#]`$``[
M6EP82__X&""@`$`X@```?'<"%$@`"-5^P[-X2__/O7[CNW@X@```.*``.$@`
M"+U+__T0B!]_7B^``$%`GOKPB!]_7R^``$-`GOKDB!]_8"^``$A`GOK8B!]_
M82^``$5`GOK,.,#_QCC@``(XH/__?T/3>$@`"#5_9-MX?T/3>#B@`"E(``BU
M/,`0`#U`$``XQEO<?XCC>']IVW@Y2ENP?\/S>#B```$XH/__?Z?K>$S&,8)(
M``M52__YB$@`"EU@````8````)0A_]`X8```?`@"II-!`!B380`<D`$`-).!
M`""3H0`DD\$`*)/A`"Q(``M)@&,``$@`"#%(``BM.````9@#```\8!``.&-:
MW$S&,8)+_]XU+`,``$&"`!"(`P``+X``,4&>`H!+_^J].&```$@`"P6`8P``
M2``'[3R`$``XH``!.(1<(#C```M(``>)+`,``$&"`I`_H!`"@6,`##O````[
MO<&,.^```8$]$`R#:P`8+XD``4&=`#1(``"L8````(")``Q_@^-X2``*R2^#
M``!`G@"0@3T0##O_``$[W@`!?XGX`$"=`(`X8```2``*A8!C``!(``=M?V3;
M>'_%\W@XP```2``(W7QZ&WE!@@!4@3H``(%=$`A7ZQ`Z@`D`"'^*6"YP"P0`
M0(+_F#A@``!(``I!@&,``$@`!RF`F@``.*```#C```)(``J9?&0;>'^#XWA(
M``H]+X,``$&>_WB!/1`,.`G__W^`\`!!G@'D.&```$@`"?V`8P``2``&Y3R`
M$``XH``!.(1<*#C```5(``:!?'\;>4&"`#PX8```2``)T8!C``!(``:Y@3\`
M##R@$``XI5PL@(D``$@`!G6!/P`,@2D``(`)``AT"0!`0((!8#A@``!(``F9
M@&,``$@`!H$\@!``.*```3B$7#0XP``%2``&'7Q_&WE!@@`\/&`0`#AC6QQ,
MQC&"2__<=7Q^&WE!@@%\.&```$@`"56`8P``2``&/8$_``Q_Q?-X@(D``$@`
M!?TX8```2``)-8!C``!(``8=2``&F3@```!\:1MX.&```)@)``!(``D5@&,`
M`$@`!?U(``DY.````)`#```\8!``.&-:^$S&,8)+_]P!+X,``)!]$!!!G@%$
M.(`![4@`!(U\9AMY08(`%"^&`!%!G@`,+X;__T">`0B``0`T@T$`&(-A`!R#
M@0`@?`@#IH.A`"2#P0`H@^$`+#@A`#!.@``@8````&````"(`P`!+X```$">
M_7PX8```2``(@8!C``!(``5I/(`0`#B@``$XA%P@.,``"T@`!04L`P``0(+]
M@&````!@````/Z`0`CN]P8Q+__Y(8````#A@``!(``@]@&,``$@`!26!/P`,
M@(D``$@`!OE+__Z(+XD``4"=_AP[X``!8````#A@```[_P`!2``("8!C``!(
M``3Q?V3;>$@`!(F`'1`,?X#X`$&=_]Q+__WH8````$@`!^&`8P``2``$R8%_
M``R!/1`(@(L``("I``!+_]PU2__^B($]$`B`O1`0/&`0`#AC7&B`B0``3,8Q
M@D@`!O6`?1`(2__R'9!]$!"!/P`,@2D``(`)``AP"P0`08(`3(!I``R`G1`(
M2``%B8$_``R!?1`(?'X;>($I``"#JP``@`D`"'`+!`!!@@!(@*D`##Q@$`!_
MI.MX.&-<.'_&\WA,QC&"2``&C3A@``!(``<U@&,``$@`!!V!/P`,.*```#C`
M``*`B0``2``'B4O__Y@X8```2``'#8!C``!(``/U@3\`##B@```XP``"@(D`
M`$@`!V%\91MX2___F&````"4(?_P.&```'P(`J:0`0`42``&T8!C``!(``.Y
M/(`0`#R@$``\P!``.(1<N#BE55`XQES42``&C8`!`!0X(0`0?`@#IDZ``"!@
M````8````)0A__`X8```?`@"II`!`!1(``:!@&,``$@``VE+__^5.&```$@`
M!FV`8P``2``#53S`$``\@!``.,9;L#R@$``XA%S@.*5,,'S',W@Y````2``$
M$8`!`!0X(0`0?`@#IDZ``"````````````````!\"`*F0I\`!90A__`XP```
MD\$`")`!`!1_R`*F/]X``CO>[5R!/H``+XD``$&>``B`R0``2``"38`!`!2#
MP0`(."$`$'P(`Z9.@``@`````$Z``"!@````8````&````"4(?_0?`@"ID*?
M``63P0`HDZ$`)),A`!2300`8?+DK>'R:(WB380`<DX$`('Q[&WB0`0`TD^$`
M+'_(`J8_W@`".][L_$O_QNV#OH`$@YZ``'^=X%!_G!9Q08(`,#O@``!7X!`Z
M?V/;>']$TWA_)<MX._\``7P=`"Y\"0.F3H`$(7^?X$!!G/_<@`$`-(,A`!2#
M00`8@V$`''P(`Z:#@0`@@Z$`)(/!`"B#X0`L."$`,$Z``"``````````````
M``"4(?_P?`@"II`!`!23X0`,/^`0`CO_OM2`'__\+X#__T&>`"0[___\8```
M`&````!\"0.F3H`$(80?__PO@/__0)[_\(`!`!2#X0`,."$`$'P(`Z9.@``@
M8````&````"4(?_P?`@"II`!`!2``0`4."$`$'P(`Z9.@``@`````#U@$`*!
M:\``?6D#IDZ`!"`]8!`"@6O`!'UI`Z9.@`0@/6`0`H%KP`A]:0.F3H`$(#U@
M$`*!:\`,?6D#IDZ`!"`]8!`"@6O`$'UI`Z9.@`0@/6`0`H%KP!1]:0.F3H`$
M(#U@$`*!:\`8?6D#IDZ`!"`]8!`"@6O`''UI`Z9.@`0@/6`0`H%KP"!]:0.F
M3H`$(#U@$`*!:\`D?6D#IDZ`!"`]8!`"@6O`*'UI`Z9.@`0@/6`0`H%KP"Q]
M:0.F3H`$(#U@$`*!:\`P?6D#IDZ`!"`]8!`"@6O`-'UI`Z9.@`0@/6`0`H%K
MP#A]:0.F3H`$(#U@$`*!:\`\?6D#IDZ`!"`]8!`"@6O`0'UI`Z9.@`0@/6`0
M`H%KP$1]:0.F3H`$(#U@$`*!:\!(?6D#IDZ`!"`]8!`"@6O`3'UI`Z9.@`0@
M/6`0`H%KP%!]:0.F3H`$(#U@$`*!:\!4?6D#IDZ`!"`]8!`"@6O`6'UI`Z9.
M@`0@/6`0`H%KP%Q]:0.F3H`$(#U@$`*!:\!@?6D#IDZ`!"`]8!`"@6O`9'UI
M`Z9.@`0@/6`0`H%KP&A]:0.F3H`$(#U@$`*!:\!L?6D#IDZ`!"`]8!`"@6O`
M<'UI`Z9.@`0@/6`0`H%KP'1]:0.F3H`$(#U@$`*!:\!X?6D#IDZ`!"`]8!`"
M@6O`?'UI`Z9.@`0@/6`0`H%KP(!]:0.F3H`$(#U@$`*!:\"$?6D#IDZ`!"`]
M8!`"@6O`B'UI`Z9.@`0@/6`0`H%KP(Q]:0.F3H`$(#U@$`*!:\"0?6D#IDZ`
M!"`]8!`"@6O`E'UI`Z9.@`0@/6`0`H%KP)A]:0.F3H`$(#U@$`*!:\"<?6D#
MIDZ`!"`]8!`"@6O`H'UI`Z9.@`0@/6`0`H%KP*1]:0.F3H`$(#U@$`*!:\"H
M?6D#IDZ`!"`]8!`"@6O`K'UI`Z9.@`0@/6`0`H%KP+!]:0.F3H`$(#U@$`*!
M:\"T?6D#IDZ`!"`]8!`"@6O`N'UI`Z9.@`0@/6`0`H%KP+Q]:0.F3H`$(#U@
M$`*!:\#`?6D#IDZ`!"`]8!`"@6O`Q'UI`Z9.@`0@/6`0`H%KP,A]:0.F3H`$
M(#U@$`*!:\#,?6D#IDZ`!"`]8!`"@6O`T'UI`Z9.@`0@/6`0`H%KP-1]:0.F
M3H`$(#U@$`*!:\#8?6D#IDZ`!"`]8!`"@6O`W'UI`Z9.@`0@/6`0`H%KP.!]
M:0.F3H`$(#U@$`*!:\#D?6D#IDZ`!"`]8!`"@6O`Z'UI`Z9.@`0@/6`0`H%K
MP.Q]:0.F3H`$(#U@$`*!:\#P?6D#IDZ`!"`]8!`"@6O`]'UI`Z9.@`0@/6`0
M`H%KP/A]:0.F3H`$(#U@$`*!:\#\?6D#IDZ`!"`]8!`"@6O!`'UI`Z9.@`0@
M/6`0`H%KP01]:0.F3H`$(#U@$`*!:\$(?6D#IDZ`!"`]8!`"@6O!#'UI`Z9.
M@`0@/6`0`H%KP1!]:0.F3H`$(#U@$`*!:\$4?6D#IDZ`!"`]8!`"@6O!&'UI
M`Z9.@`0@/6`0`H%KP1Q]:0.F3H`$(#U@$`*!:\$@?6D#IDZ`!"`]8!`"@6O!
M)'UI`Z9.@`0@/6`0`H%KP2A]:0.F3H`$(#U@$`*!:\$L?6D#IDZ`!"`]8!`"
M@6O!,'UI`Z9.@`0@/6`0`H%KP31]:0.F3H`$(#U@$`*!:\$X?6D#IDZ`!"`]
M8!`"@6O!/'UI`Z9.@`0@2``!0$@``3Q(``$X2``!-$@``3!(``$L2``!*$@`
M`21(``$@2``!'$@``1A(``$42``!$$@``0Q(``$(2``!!$@``0!(``#\2```
M^$@``/1(``#P2```[$@``.A(``#D2```X$@``-Q(``#82```U$@``-!(``#,
M2```R$@``,1(``#`2```O$@``+A(``"T2```L$@``*Q(``"H2```I$@``*!(
M``"<2```F$@``)1(``"02```C$@``(A(``"$2```@$@``'Q(``!X2```=$@`
M`'!(``!L2```:$@``&1(``!@2```7$@``%A(``!42```4$@``$Q(``!(2```
M1$@``$!(```\2```.$@``#1(```P2```+$@``"A(```D8````&````!@````
M8````&````!@````8````&`````]@!`"/6OP`(`,O_@Y:Z?@?`D#IGP+6A2!
MC+_\?6!:%$Z`!"!@````8````&````!@````8````&````!@````E"'_\'P(
M`J:0`0`4D\$`"$*?``5_R`*F/]X``3O>9D!+_[_1@`$`%'P(`Z:#P0`(."$`
M$$Z``"`0`D%0$``\T!``4>`0`%'0``(``1``7/@0`%TP$`!=0!``74@0`%U0
M$`!=6!``6[`0`%TL7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M````$`!='!``7200`%N\$`!;L!``6VP0`%MP$`!=$!``6OP0`%T8$`!;L!``
M7/P0`%T$$`!;L%F``````````````$'/____@```4$%27T-,14%.````+W!R
M;V,O<V5L9B]E>&4``"5S+R5S````+W!R;V,O)6DO)7,`97AE`"5S)7,E<P``
M4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?5$5-4`````!005)?1$5"54<`
M``!005)?0T%#2$4```!005)?4%)/1TY!344`````4$%27T%21T,`````4$%2
M7T%21U9?,```4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)
M4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`````%!!4E]#3$5!3CT``#$```!P87(M`````"UE```M+0``+@```"5S
M)7,E<R5S`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)3`R
M>``````E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P````!365-4
M14T``$%21U8`````&````'!E<FP`````,````"5S.B!E>&5C=71I;VX@;V8@
M)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@
M86)O<G1I;F<@=VET:"`E:2X*````1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`'!E<FQX<VDN8P```$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"\```!5
M4T52`````%5315).04U%`````%1%35!$25(`5$U0`$,Z7%1%35``+W1M<```
M```Z````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(````
M`$193$1?3$E"4D%265]0051(````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R
M7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U
M;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@
M,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI4
M96UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@
M1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D
M:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S
M"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O
M;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N
M('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@
M("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@
M=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL
M(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y
M('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N
M(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@
M("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@
M("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U0
M3$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)
M6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@
M("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@
M("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@
M,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^
M9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S
M92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q
M*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@
M?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?
M:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@
M)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!
M4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D
M,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@
M)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=6
M7R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC
M(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I
M9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU3
M5VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@
M<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE
M<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T
M>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D[
M"@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@
M7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N
M<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I
M+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E
M86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T
M.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@
M("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*
M("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@
M("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@
M("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X
M="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U
M="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@
M("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M
M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@
M/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@
M(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N
M(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@
M("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F
M.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@
M("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D
M9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`
M24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@
M("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@
M("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@
M("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K
M97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@
M("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@
M)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*
M("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M
M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R
M(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@
M("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]
M+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[
M>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*
M("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD[
M"B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@
M9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D
M(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE
M(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L
M;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7
M:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M
M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@
M(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@
M("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G
M<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@
M("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@
M<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*
M(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T
M86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O
M<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@
M("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R
M"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L
M;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y
M7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B
M87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!
M4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L
M(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@
M:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER
M;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D
M9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@
M("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@
M("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E
M=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)T\G*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@
M("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D
M8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2![
M"B`@("`@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@
M("1C86-H95]N86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!
M4E]414U0)WT["B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@
M("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@
M("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@
M("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC
M(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U
M='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("![
M"B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@
M("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P
M87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F
M:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O
M<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@
M("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G
M(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@
M("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%
M5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@
M("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@
M?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![
M>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@
M>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A
M<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I
M<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T
M(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE
M("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A
M=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P
M+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@
M;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D
M:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K
M97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T
M:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@
M("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]
M?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D
M8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@
M(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET
M7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@
M;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L
M96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T10
M04XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@
M(&EF("@D0V]N9FEG>U]D96QI;7T@97$@)UQ<)RD@>R!S>UQ<?7LO?6<@9F]R
M($!I;F,@?0H*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@
M9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@
M96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L
M:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@
M;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B
M;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I
M;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3
M=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@
M86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@
M("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@
M(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I
M;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@
M("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@
M("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@
M("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@
M("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@
M("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<
M6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@
M;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@
M("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@
M("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL
M92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E
M;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*
M("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@
M("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@
M("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@
M(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV
M:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K
M<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@
M("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N
M86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@
M("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@
M("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]
M"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M
M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H
M95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@
M("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X
M(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?
M=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@
M>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C
M='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X
M(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE
M7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@
M("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M
M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@
M("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N
M86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@
M("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!
M4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A
M;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS
M,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*
M("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@
M("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@
M("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@
M(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@
M("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@
M("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@
M("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@
M("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@
M("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@
M("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@
M("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC
M($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM[
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M
M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA
M;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"
M87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@
M(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP
M871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I
M=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@
M("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R
M97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER
M92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@
M17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I
M<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&
M:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER
M92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)
M3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@
M(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q
M=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E
M<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@
M:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN
M(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T
M7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E
M;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M
M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z
M7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@
M("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C
M(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@
M(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N
M86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER
M("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@
M("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@
M("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@
M("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@
M("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@
M("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@
M("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D
M8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL
M96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D
M9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N
M86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@
M("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV
M97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S
M971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@
M("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D
M,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@
M/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X]
M(#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE
M*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@
M("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@
M("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL
M(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@
M("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@
M("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@
M("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R
M;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@
M("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@
M:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,
M3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A
M<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[
M4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K
M*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970[
M"B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN
M(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@
M('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*
M(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K
M86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N
M86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,@H*7U]%3D1?7PH`
M``!P87(N<&P```$;`SL````0`````?__8!`````H````$``````!>E(`!'Q!
M`1L,`0`````0````&/__7^`````D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#_____`````/____\``````````!`!
MP4@0`;[0$`&^T`````$````!`````0```K(````!```"O0````$```+'````
M`0```Q8````!```$9`````P0`!D0````#1``6:`````$$``!J&___O40``4$
M````!1``#9P````&$``&7`````H```8(````"P```!`````5``````````,0
M`<```````@```\`````4````!P```!<0`!50<````!`!O_0````'$``5+```
M``@```/D````"0````QO___^$``4C&____\````";___\!``$Z0`````````
M````````````````````````````````````````````````````````````
M$`&^\```````````$`!8(!``6"00`%@H$`!8+!``6#`0`%@T$`!8.!``6#P0
M`%A`$`!81!``6$@0`%A,$`!84!``6%00`%A8$`!87!``6&`0`%AD$`!8:!``
M6&P0`%AP$`!8=!``6'@0`%A\$`!8@!``6(00`%B($`!8C!``6)`0`%B4$`!8
MF!``6)P0`%B@$`!8I!``6*@0`%BL$`!8L!``6+00`%BX$`!8O!``6,`0`%C$
M$`!8R!``6,P0`%C0$`!8U!``6-@0`%C<$`!8X!``6.00`%CH$`!8[!``6/`0
M`%CT$`!8^!``6/P0`%D`$`!9!!``60@0`%D,$`!9$!``6100`%D8$`!9'!``
M62`0`%DD$`!9*!``62P0`%DP$`!9-!``63@0`%D\$`!90!``6400`%E($`!9
M3!``65`0`%E4$`!96!``65P```````````````#_____$`"Y2```6]E'0T,Z
M("A58G5N='4@-"XT+C(M.75B=6YT=30I(#0N-"XS(#(P,3`P,3$V("AP<F5R
M96QE87-E*0!!````$V=N=0`!````"P0!"`$,`@`N<VAS=')T86(`+FEN=&5R
M<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YG
M;W0R`"YD>6YA;6EC`"YG;W0`+F1A=&$`+G-D871A`"YB<W,`+F-O;6UE;G0`
M+F=N=2YA='1R:6)U=&5S````````````````````````````````````````
M````````````````````"P````$````"$``!5````50````-````````````
M```!`````````!,````'`````A```60```%D````(```````````````!```
M```````A````!P````(0``&$```!A````"0```````````````0`````````
M.`````4````"$``!J````:@```-<````!@`````````$````!````#1O___V
M`````A``!00```4$```!6`````8`````````!`````0````^````"P````(0
M``9<```&7```!T`````'`````0````0````0````1@````,````"$``-G```
M#9P```8(```````````````!`````````$YO____`````A``$Z0``!.D````
MZ`````8``````````@````(```!;;____@````(0`!2,```4C````*`````'
M`````@````0`````````:@````0````"$``5+```%2P````D````!@``````
M```$````#````'0````$`````A``%5```!50```#P`````8````8````!```
M``P```!^`````0````80`!D0```9$````$P```````````````0`````````
MA`````$````&$``98```&6```$!````````````````0`````````(H````!
M````!A``6:```%F@````.```````````````!`````````"0`````0````(0
M`%G8``!9V```7W@```````````````@`````````F`````$````"$`"Y4```
MN5`````4```````````````$`````````*8````!`````A``N60``+ED````
M+```````````````!`````````"P`````0````,0`;[0``"^T`````@`````
M``````````0`````````MP````$````#$`&^V```OM@````(````````````
M```$`````````+X````!`````Q`!ON```+[@````!```````````````!```
M``````##`````0````,0`;[D``"^Y`````P```````````````$`````````
MR0````8````#$`&^\```OO````$`````!P`````````$````"````-(````!
M`````Q`!O_```+_P````$```````````````!`````0```!Y`````0````,0
M`<````#``````4````````````````0`````````UP````$````#$`'!0```
MP4`````0```````````````$`````````-T````!`````Q`!P5```,%0````
M"```````````````!`````````#D````"`````,0`<%@``#!6```$$``````
M`````````!``````````Z0````$````P````````P5@````Y````````````
M```!`````0```/)O___U`````````````,&1````%````````````````0``
J```````!`````P````````````#!I0```0(```````````````$`````
